@@ -91,7 +91,6 @@ function DisplayUpcomingList(&$module, $id, &$parameters, $returnid)
 
 
   // build the query
-  $sql1 = "SELECT COUNT($events_table_name.event_id) AS count FROM $events_table_name";
   $where = 'WHERE';
   $sql2 = "SELECT $events_table_name.* FROM $events_table_name";
   if(!empty($category))
@@ -100,7 +99,6 @@ function DisplayUpcomingList(&$module, $id, &$parameters, $returnid)
 		  ON $events_table_name.event_id = $events_to_categories_table_name.event_id
 	       INNER JOIN $categories_table_name
 	          ON $events_to_categories_table_name.category_id = $categories_table_name.category_id";
-      $sql1 .= " ".$txt;
       $sql2 .= " ".$txt;
     }
 
@@ -122,7 +120,6 @@ function DisplayUpcomingList(&$module, $id, &$parameters, $returnid)
                     )
                   )";
   }
-  $sql1 .= ' '.$txt;
   $sql2 .= ' '.$txt;
   $where = ' AND ';
 
@@ -136,16 +133,15 @@ function DisplayUpcomingList(&$module, $id, &$parameters, $returnid)
 	  $tmp[] = "($categories_table_name.category_name LIKE '$cat')";
 	}
       $txt = '('.implode(' OR ',$tmp).')';
-      $sql1 .= ' AND '.$txt;
       $sql2 .= ' AND '.$txt;
     }
 
-  if( !isset($parameters['unique_only']) || $parameters['unique_only'] == 0 )
+  if( !isset($parameters['unique_only']) || $parameters['unique_only'] == 1 )
     {
-      $sql1 .= " GROUP BY $events_table_name.event_title";
       $sql2 .= " GROUP BY $events_table_name.event_title";
     }
 
+  $sql1 = 'SELECT COUNT(*) FROM ('.$sql2.') AS sub';
   $sql2 .= " ORDER BY $events_table_name.event_date_start $sorting";
 
 
