@@ -1,4 +1,11 @@
 <?php
+$lang['dflt_urlprefix'] = 'Pr&eacute;fixe d&#039;URL par d&eacute;faut pour &quot;pretty URLS&quot;';
+$lang['dflt_alldayevent'] = 'Les nouveaux &eacute;v&eacute;nements sont des &eacute;v&eacute;nements &quot;jour entier (all day)&quot; par d&eacute;faut';
+$lang['dflt_starttime'] = 'Heure de d&eacute;but par d&eacute;faut pour les nouveaux &eacute;v&eacute;nements';
+$lang['info_dflt_starttime'] = '<em>(S&#039;applique uniquement si les nouveaux &eacute;v&eacute;nements ne sont pas des &eacute;v&eacute;nements &quot;jour entier / All Day&quot;.)</em>';
+$lang['search_type'] = 'Type de recherche';
+$lang['search_any'] = 'renvoie le r&eacute;sultat sur n&#039;importe lequel des mots recherch&eacute;s';
+$lang['search_all'] = 'renvoie le r&eacute;sultat de recherche sur tous les mots recherch&eacute;s';
 $lang['info_customfields'] = '<span style=&quot;color: red;&quot;>Note : </span>aucune recherche ne peut &ecirc;tre effectu&eacute;e sur &quot;File Upload Fields&quot;.';
 $lang['searchable'] = 'Utilisable comme crit&egrave;re de recherche';
 $lang['help_param_editeventtemplate'] = 'Applicable uniquement pour l&#039;action Mes &Eacute;v&eacute;nements, ce param&egrave;tre permet de sp&eacute;cifier un autre gabarit d&#039;&eacute;dition d&#039;&eacute;v&eacute;nement (invoqu&eacute; lorsque l&#039;utilisateur cr&eacute;e ou &eacute;dite un &eacute;v&eacute;nement) que celui utilis&eacute; par d&eacute;faut.';
@@ -541,4 +548,8 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>
 ';
+$lang['utma'] = '156861353.3775108633884901000.1235391363.1284418363.1285534821.75';
+$lang['utmz'] = '156861353.1284418375.74.34.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
+$lang['qca'] = 'P0-186310954-1257243985177';
+$lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
